﻿using System.Windows;
using System.Windows.Controls;

namespace XamPivotGridSample
{
    using Infragistics.Controls.Grids;
    using Infragistics.DragDrop;
    using Infragistics.Olap;
    using Infragistics.Olap.Data;

    public class DropTriggerActionEx : XamTriggerAction<DragSource>
    {
        protected override void Invoke(object parameter)
        {
            DropEventArgs args = parameter as DropEventArgs;
            if (args == null)
            {
                return;
            }

            FrameworkElement dropTarget = args.DropTarget as FrameworkElement;
            
            // check the targets because it's invoked no matter where the item is dropped
            if (dropTarget == null || dropTarget.Name != "externalDropTarget")
            {
                return;
            }

            // here you'll use your logic to process the drop target
            Panel panel = dropTarget as Panel;
            if (panel == null)
            {
                return;
            }

            string dataName = string.Empty;

            // there are possible four different type of objects passed as data:
            // IHierarchy, IFilterViewModel, IMeasure, IMeasureViewModel
            // depends on their drag source
            IHierarchy hierarchy = args.Data as IHierarchy;
            if (hierarchy == null)
            {
                IFilterViewModel filterViewModel = args.Data as IFilterViewModel;
                if (filterViewModel != null)
                {
                    hierarchy = filterViewModel.Hierarchy;
                }
            }

            if (hierarchy == null)
            {
                IMeasure measure = args.Data as IMeasure;
                if (measure == null)
                {
                    IMeasureViewModel measureViewModel = args.Data as IMeasureViewModel;
                    if (measureViewModel != null)
                    {
                        measure = measureViewModel.Measure;
                    }
                }

                if (measure != null)
                {
                    dataName = measure.UniqueName;
                }
            }
            else
            {
                dataName = hierarchy.UniqueName;
            }

            if (dataName == string.Empty)
            {
                return;
            }

            panel.Children.Add(new TextBlock { Text = dataName });
        }
    }
}
